@@ -2,7 +2,7 @@
 """Main Controller"""
 from tg import TGController
 from tg import expose, flash, require, url, lurl, request, redirect, validate, tmpl_context, config
-from tg.decorators import before_render, cached_property
+from tg.decorators import before_render, cached_property, paginate
 from tg.i18n import ugettext as _, lazy_ugettext as l_
 
 try:
@@ -101,6 +101,7 @@ class RootController(TGController):
 
     @require(predicates.in_group('smallpress'))
     @expose('genshi:smallpress.templates.manage')
+    @paginate('articles')
     def manage(self, blog='', *args, **kw):
         articles = Article.get_all(blog)
         return dict(table=articles_table, articles=articles,
